<?php
defined('MOODLE_INTERNAL') || die();

/**
 * Handles the upgrade process for the block_zoomonline plugin.
 *
 * @param int $oldversion The version of the plugin before the upgrade.
 * @return bool True on successful upgrade.
 */
function xmldb_block_zoomonline_upgrade($oldversion) {
    global $DB;

    $dbman = $DB->get_manager(); // Database manager.

    // Ensure the block_zoomonline_links table exists and is correct.
    if ($oldversion < 2025012504) {
        $table = new xmldb_table('block_zoomonline_links');

        // Define fields for the table.
        $fields = [
                new xmldb_field('id', XMLDB_TYPE_INTEGER, '10', null, XMLDB_NOTNULL, XMLDB_SEQUENCE, null),
                new xmldb_field('zoom_meeting_id', XMLDB_TYPE_CHAR, '45', null, null, null, null),
                new xmldb_field('lecturer_id', XMLDB_TYPE_CHAR, '45', null, null, null, null),
                new xmldb_field('course_id', XMLDB_TYPE_CHAR, '45', null, null, null, null),
                new xmldb_field('crscode', XMLDB_TYPE_CHAR, '90', null, null, null, null),
                new xmldb_field('groupid', XMLDB_TYPE_CHAR, '90', null, null, null, null),
                new xmldb_field('visible', XMLDB_TYPE_INTEGER, '1', null, XMLDB_NOTNULL, null, '1'),
        ];

        // Define the primary key.
        $key = new xmldb_key('id', XMLDB_KEY_PRIMARY, ['id']);

        // Create the table if it doesn't exist.
        if (!$dbman->table_exists($table)) {
            foreach ($fields as $field) {
                $table->add_field($field);
            }
            $table->add_key($key);
            $dbman->create_table($table);
        } else {
            // Ensure all fields exist.
            foreach ($fields as $field) {
                if (!$dbman->field_exists($table, $field)) {
                    $dbman->add_field($table, $field);
                }
            }
        }

        // Savepoint for this upgrade step.
         upgrade_block_savepoint(true, 2025012504, 'zoomonline');
    }

    // Ensure the block_zoomonline_att_check table exists and is correct.
    if ($oldversion < 2025012504) {
        $table = new xmldb_table('block_zoomonline_att_check');

        // Define fields for the table.
        $fields = [
                new xmldb_field('id', XMLDB_TYPE_INTEGER, '10', null, XMLDB_NOTNULL, XMLDB_SEQUENCE, null),
                new xmldb_field('zoom_meeting_id', XMLDB_TYPE_CHAR, '45', null, null, null, null),
                new xmldb_field('start_date', XMLDB_TYPE_DATETIME, null, null, null, null),
        ];

        // Define the primary key.
        $key = new xmldb_key('id', XMLDB_KEY_PRIMARY, ['id']);

        // Create the table if it doesn't exist.
        if (!$dbman->table_exists($table)) {
            foreach ($fields as $field) {
                $table->add_field($field);
            }
            $table->add_key($key);
            $dbman->create_table($table);
        } else {
            // Ensure all fields exist.
            foreach ($fields as $field) {
                if (!$dbman->field_exists($table, $field)) {
                    $dbman->add_field($table, $field);
                }
            }
        }

        // Savepoint for this upgrade step.
         upgrade_block_savepoint(true, 2025012504, 'zoomonline');
    }

    // Ensure the block_zoomonline_token table exists and is correct.
    if ($oldversion < 2025012504) {
        $table = new xmldb_table('block_zoomonline_token');

        // Define fields for the table.
        $fields = [
                new xmldb_field('id', XMLDB_TYPE_INTEGER, '10', null, XMLDB_NOTNULL, XMLDB_SEQUENCE, null),
                new xmldb_field('access_token', XMLDB_TYPE_CHAR, '1000', null, null, null, null),
                new xmldb_field('current', XMLDB_TYPE_INTEGER, '11', null, null, null, null),
        ];

        // Define the primary key.
        $key = new xmldb_key('id', XMLDB_KEY_PRIMARY, ['id']);

        // Create the table if it doesn't exist.
        if (!$dbman->table_exists($table)) {
            foreach ($fields as $field) {
                $table->add_field($field);
            }
            $table->add_key($key);
            $dbman->create_table($table);
        } else {
            // Ensure all fields exist.
            foreach ($fields as $field) {
                if (!$dbman->field_exists($table, $field)) {
                    $dbman->add_field($table, $field);
                }
            }
        }

        // Savepoint for this upgrade step.
         upgrade_block_savepoint(true, 2025012504, 'zoomonline');
    }

    return true;
}
